/**
 * Javascript ALSA aplay and amixer wrapper for Node.js
 *
 * @mantainedBy Jesse Kirschner - @JesseKirschner
 * @author Rocco Musolino - @roccomuso
 * @author Patrik Melander (lotAballs) node-aplay module
 * @originalAuthor Maciej Sopyło - @KILLAHFORGE
 *
 * Dependencies: sudo apt-get install alsa-base alsa-utils
 * MIT License
 */
/// <reference types="node" />
import EventEmitter from 'events';
interface SoundOptions {
    volume?: number;
    channelMap?: ChannelMap[];
}
declare type ChannelMap = 'left' | 'right' | 'front-left' | 'front-right' | 'mono' | 'front-center' | 'rear-left' | 'rear-right' | 'rear-center' | 'lfe' | 'front-left-of-center' | 'front-right-of-center' | 'side-left' | 'side-right' | 'top-center' | 'top-front-center' | 'top-front-left' | 'top-front-right' | 'top-rear-left' | 'top-rear-right' | 'top-rear-center';
export declare class Sound extends EventEmitter {
    private _sink_input_id?;
    private _volume;
    private _process?;
    private _stopped;
    private _channelMap;
    constructor(options?: SoundOptions);
    /**
     * Play file once, for x amount of loops or loop indefinitly
     *
     * @param {string} fileName - absolute path of file
     * @param {number} loops - amount of loops, or -1 for endless loops
     * @returns self
     */
    play(fileName?: string, loops?: number): this;
    setVolume(volume: number): this;
    stop(): this;
    pause(): this;
    resume(): this;
    isPlaying(): boolean;
}
export {};
