"use strict";
/**
 * Javascript ALSA aplay and amixer wrapper for Node.js
 *
 * @mantainedBy Jesse Kirschner - @JesseKirschner
 * @author Rocco Musolino - @roccomuso
 * @author Patrik Melander (lotAballs) node-aplay module
 * @originalAuthor Maciej Sopyło - @KILLAHFORGE
 *
 * Dependencies: sudo apt-get install alsa-base alsa-utils
 * MIT License
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sound = void 0;
var child_process_1 = require("child_process");
var events_1 = __importDefault(require("events"));
var relative_to_absolute_volume = function (relative_volume) {
    var volume = Math.max(0, Math.min(100, relative_volume));
    return Math.floor((65536 / 100) * volume);
};
var Sound = /** @class */ (function (_super) {
    __extends(Sound, _super);
    function Sound(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this) || this;
        _this._volume = 45000;
        _this._stopped = true;
        _this._channelMap = ['left', 'right'];
        if (options.volume) {
            _this._volume = relative_to_absolute_volume(options.volume);
        }
        if (options.channelMap) {
            _this._channelMap = options.channelMap;
        }
        return _this;
    }
    /**
     * Play file once, for x amount of loops or loop indefinitly
     *
     * @param {string} fileName - absolute path of file
     * @param {number} loops - amount of loops, or -1 for endless loops
     * @returns self
     */
    Sound.prototype.play = function (fileName, loops) {
        var _this = this;
        if (loops === void 0) { loops = 0; }
        this._stopped = false;
        if (this._process)
            this._process.kill('SIGTERM');
        var args = [
            "--volume=" + this._volume,
            "--channels=" + this._channelMap.length,
            "--channel-map=" + this._channelMap,
        ];
        if (fileName)
            args = args.concat([fileName]);
        this._process = child_process_1.spawn('pacat', args);
        this._process.on('spawn', function () {
            child_process_1.exec('pacmd list-sink-inputs', {}, function (error, stdout) {
                stdout.split('index: ').forEach(function (sinkInput) {
                    if (fileName && sinkInput.includes(fileName)) {
                        _this._sink_input_id = sinkInput.split(/\r?\n/)[0];
                    }
                });
            });
        });
        this._process.on('exit', function (code, sig) {
            if (loops != 0) {
                _this.play(fileName, loops - 1);
            }
            else {
                _this._stopped = true;
                if (code !== null && sig === null)
                    _this.emit('complete');
            }
        });
        return this;
    };
    Sound.prototype.setVolume = function (volume) {
        this._volume = relative_to_absolute_volume(volume);
        child_process_1.exec("pacmd set-sink-input-volume " + this._sink_input_id + " " + this._volume);
        return this;
    };
    Sound.prototype.stop = function () {
        if (this._process) {
            this._stopped = true;
            this._process.kill('SIGTERM');
            this.emit('stop');
        }
        return this;
    };
    Sound.prototype.pause = function () {
        if (this._process) {
            if (this._stopped)
                return this;
            this._process.kill('SIGSTOP');
            // exec(`pactl suspend-source ${this._sink_input_id} 1`);
            this.emit('pause');
        }
        return this;
    };
    Sound.prototype.resume = function () {
        if (this._process) {
            if (this._stopped)
                return this.play();
            // exec(`pactl suspend-source ${this._sink_input_id} 0`);
            this._process.kill('SIGCONT');
            this.emit('resume');
        }
        return this;
    };
    Sound.prototype.isPlaying = function () {
        return !this._stopped;
    };
    return Sound;
}(events_1.default));
exports.Sound = Sound;
